import logging
import os
import uuid
import boto3
from tic.shared.statsd_client import StatsdClient
from tic.mfg.shared import logging_config

false_values = [False, "False", "false", "FALSE", 0, "N", "n", "No", "no", "NO", None]


class BaseMfgConfig:
    def __init__(
        self,
        service_name: str,
        statsd_prefix: str = None,
        need_database_config: bool = False,
    ):
        local_invoke = False if os.getenv("LOCAL_INVOKE") in false_values else True
        self.service_name = service_name
        if statsd_prefix:
            self.statsd_prefix = statsd_prefix
        else:
            self.statsd_prefix = f"tic.mfg.{service_name}"
        # AWS Configs
        self.account = os.getenv("ACCOUNT", "211409013885")
        self.region = os.getenv("AWS_REGION", "us-east-1").lower()
        self.profile = os.getenv("PROFILE", "tic-dev").lower()
        self.stage = os.getenv("STAGE", "dev").lower()
        self.log_level = os.getenv("LOGLEVEL", "INFO")

        self.boto_session = boto3.Session(region_name=self.region)
        if local_invoke:
            self.boto_session.session.set_config_variable("profile", self.profile)

        # Logging configuration
        logging_config.configure_logging(
            level=self.log_level, service=self.service_name, instance=str(uuid.uuid4())
        )
        self.logger = logging.getLogger()

        # Configure StatsD
        stats_host = os.getenv("TELEGRAF_PROXY_EXTERNAL_DNS") or os.getenv(
            "STATSD_HOST"
        )
        stats_port = os.getenv("TELEGRAF_PROXY_STATSD_PORT") or os.getenv("STATSD_PORT")
        if stats_host:
            os.environ["statsd_host"] = stats_host
        if stats_port:
            os.environ["statsd_port"] = stats_port
        self.statsd = StatsdClient(
            prefix=self.statsd_prefix,
            logger=self.logger,
        )

        if need_database_config:
            # MFG Database (AWS Aurora Postgres)
            self.mfg_db_schema = os.getenv("MFG_DB_SCHEMA", "dbo")
            self.mfg_db_host = os.getenv("MFG_DB_HOST", "localhost")
            self.mfg_db_port = int(os.getenv("MFG_DB_PORT", 5432))
            self.mfg_db_name = os.getenv("MFG_DB_NAME", "mfg")
            self.mfg_db_username = os.getenv("MFG_DB_USERNAME")
            self.mfg_db_password = os.getenv("MFG_DB_PASSWORD")
            self.mfg_db_is_password_encrypted = (
                False
                if os.getenv("MFG_DB_IS_PASSWORD_ENCRYPTED") in false_values
                else True
            )
            self.mfg_db_enable_ssl = (
                False
                if os.getenv("MFG_DB_ENABLE_SSL", "False") in false_values
                else True
            )
            self.mfg_db_ssl_mode = os.getenv("MFG_DB_SSL_MODE", "verify_ca")
